==> general_cli-0.0.7.tar.gz: template/app_template/lib/app_template.dart <==
import 'package:app_template/app_template_data/app_template_data.dart';
import 'package:app_template/page/sign.dart';
import 'package:flutter/material.dart';
import 'package:general_lib_flutter/general_lib_flutter.dart';

class AppTemplate extends StatefulWidget {
  final ValueNotifier<ThemeMode> themeModeNotifier;
  const AppTemplate({super.key, required this.themeModeNotifier});

  @override
  State<AppTemplate> createState() => _AppTemplateState();
}

class _AppTemplateState extends State<AppTemplate> {
  @override
  void initState() {
    super.initState();
    // widget.;
    WidgetsBinding.instance.addPostFrameCallback((Duration duration) async {
      await task();
    });
  }

  Future<void> task() async {
    Future(() async {
      AppTemplateData appTemplateData =
          AppTemplateData(themeModeNotifier: widget.themeModeNotifier);
      await context.navigator().pushReplacement(
        MaterialPageRoute(
          builder: (context) {
            SignPageAppTemplate signPageAppTemplate =
                SignPageAppTemplate(appTemplateData: appTemplateData);

            // if (signPageAppTemplate.isDebug) {
            //   return AppDebug(
            //     themeMode: widget.themeModeNotifier,
            //     child: signPage,
            //   );
            // } else {
            return signPageAppTemplate;
            // }
          },
        ),
      );
    });
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      floatingActionButton: FloatingActionButton(
        onPressed: () {},
        child: Icon(Icons.add),
      ),
    );
  }
}

==> general_cli-0.0.10.tar.gz: template/app_template/lib/app_template.dart <==
import 'package:app_template/app_template_data/app_template_data.dart';
import 'package:app_template/page/sign.dart';
import 'package:flutter/material.dart';
import 'package:general_lib_flutter/general_lib_flutter.dart';

class AppTemplate extends StatefulWidget {
  final ValueNotifier<ThemeMode> themeModeNotifier;
  const AppTemplate({super.key, required this.themeModeNotifier});

  @override
  State<AppTemplate> createState() => _AppTemplateState();
}

class _AppTemplateState extends State<AppTemplate> {
  @override
  void initState() {
    super.initState();

    WidgetsBinding.instance.addPostFrameCallback((Duration duration) async {
      await task();
    });
  }

  Future<void> task() async {
    Future(() async {
      AppTemplateData appTemplateData = AppTemplateData(themeModeNotifier: widget.themeModeNotifier);
      await context.navigator().pushReplacement(
        MaterialPageRoute(
          builder: (context) {
            SignPageAppTemplate signPageAppTemplate = SignPageAppTemplate(appTemplateData: appTemplateData);

            // if (signPageAppTemplate.isDebug) {
            //   return AppDebug(
            //     themeMode: widget.themeModeNotifier,
            //     child: signPage,
            //   );
            // } else {
            return signPageAppTemplate;
            // }
          },
        ),
      );
    });
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      floatingActionButton: FloatingActionButton(
        onPressed: () {},
        child: Icon(Icons.add),
      ),
    );
  }
}
